# -*- coding: utf-8 -*-
#---------------------------------------------------------------------------
# Copyright 2023 VMware, Inc.  All rights reserved.

# AUTO GENERATED FILE -- DO NOT MODIFY!
#
# vAPI stub file for package com.vmware.appliance.recovery.restore.
#---------------------------------------------------------------------------

"""


"""

__author__ = 'VMware, Inc.'
__docformat__ = 'restructuredtext en'

import sys
from warnings import warn

from vmware.vapi.bindings import type
from vmware.vapi.bindings.converter import TypeConverter
from vmware.vapi.bindings.enum import Enum
from vmware.vapi.bindings.error import VapiError
from vmware.vapi.bindings.struct import VapiStruct
from vmware.vapi.bindings.stub import (
    ApiInterfaceStub, StubFactoryBase, VapiInterface)
from vmware.vapi.bindings.common import raise_core_exception
from vmware.vapi.data.validator import (UnionValidator, HasFieldsOfValidator)
from vmware.vapi.exception import CoreException
from vmware.vapi.lib.constants import TaskType
from vmware.vapi.lib.rest import OperationRestMetadata


class Job(VapiInterface):
    """
    ``Job`` class provides methods Performs restore operations
    """

    _VAPI_SERVICE_ID = 'com.vmware.appliance.recovery.restore.job'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _JobStub)
        self._VAPI_OPERATION_IDS = {}

    class ReturnStatus(Enum):
        """
        ``Job.ReturnStatus`` class Defines the state of precheck

        .. note::
            This class represents an enumerated type in the interface language
            definition. The class contains class attributes which represent the
            values in the current version of the enumerated type. Newer versions of
            the enumerated type may contain new values. To use new values of the
            enumerated type in communication with a server that supports the newer
            version of the API, you instantiate this class. See :ref:`enumerated
            type description page <enumeration_description>`.
        """
        FAIL = None
        """
        Check failed

        """
        WARNING = None
        """
        Passed with warnings

        """
        OK = None
        """
        Check passed

        """

        def __init__(self, string):
            """
            :type  string: :class:`str`
            :param string: String value for the :class:`ReturnStatus` instance.
            """
            Enum.__init__(string)

    ReturnStatus._set_values({
        'FAIL': ReturnStatus('FAIL'),
        'WARNING': ReturnStatus('WARNING'),
        'OK': ReturnStatus('OK'),
    })
    ReturnStatus._set_binding_type(type.EnumType(
        'com.vmware.appliance.recovery.restore.job.return_status',
        ReturnStatus))


    class LocationType(Enum):
        """
        ``Job.LocationType`` class Defines type of all locations for backup/restore

        .. note::
            This class represents an enumerated type in the interface language
            definition. The class contains class attributes which represent the
            values in the current version of the enumerated type. Newer versions of
            the enumerated type may contain new values. To use new values of the
            enumerated type in communication with a server that supports the newer
            version of the API, you instantiate this class. See :ref:`enumerated
            type description page <enumeration_description>`.
        """
        FTP = None
        """
        Destination is FTP server

        """
        HTTP = None
        """
        Destination is HTTP server

        """
        FTPS = None
        """
        Destination is FTPS server

        """
        HTTPS = None
        """
        Destination is HTTPS server

        """
        SCP = None
        """
        Destination is SSH server

        """
        SFTP = None
        """
        Destination is SFTP server

        """
        NFS = None
        """
        Destination is NFS server. This class attribute was added in vSphere API
        6.7.2.

        """
        SMB = None
        """
        Destination is SMB server. This class attribute was added in vSphere API
        6.7.2.

        """

        def __init__(self, string):
            """
            :type  string: :class:`str`
            :param string: String value for the :class:`LocationType` instance.
            """
            Enum.__init__(string)

    LocationType._set_values({
        'FTP': LocationType('FTP'),
        'HTTP': LocationType('HTTP'),
        'FTPS': LocationType('FTPS'),
        'HTTPS': LocationType('HTTPS'),
        'SCP': LocationType('SCP'),
        'SFTP': LocationType('SFTP'),
        'NFS': LocationType('NFS'),
        'SMB': LocationType('SMB'),
    })
    LocationType._set_binding_type(type.EnumType(
        'com.vmware.appliance.recovery.restore.job.location_type',
        LocationType))


    class BackupRestoreProcessState(Enum):
        """
        ``Job.BackupRestoreProcessState`` class Defines state of backup/restore
        process

        .. note::
            This class represents an enumerated type in the interface language
            definition. The class contains class attributes which represent the
            values in the current version of the enumerated type. Newer versions of
            the enumerated type may contain new values. To use new values of the
            enumerated type in communication with a server that supports the newer
            version of the API, you instantiate this class. See :ref:`enumerated
            type description page <enumeration_description>`.
        """
        FAILED = None
        """
        Failed

        """
        INPROGRESS = None
        """
        In progress

        """
        NONE = None
        """
        Not started

        """
        SUCCEEDED = None
        """
        Completed successfully

        """

        def __init__(self, string):
            """
            :type  string: :class:`str`
            :param string: String value for the :class:`BackupRestoreProcessState` instance.
            """
            Enum.__init__(string)

    BackupRestoreProcessState._set_values({
        'FAILED': BackupRestoreProcessState('FAILED'),
        'INPROGRESS': BackupRestoreProcessState('INPROGRESS'),
        'NONE': BackupRestoreProcessState('NONE'),
        'SUCCEEDED': BackupRestoreProcessState('SUCCEEDED'),
    })
    BackupRestoreProcessState._set_binding_type(type.EnumType(
        'com.vmware.appliance.recovery.restore.job.backup_restore_process_state',
        BackupRestoreProcessState))


    class LocalizableMessage(VapiStruct):
        """
        ``Job.LocalizableMessage`` class Structure representing message

        .. tip::
            The arguments are used to initialize data attributes with the same
            names.
        """




        def __init__(self,
                     id=None,
                     default_message=None,
                     args=None,
                    ):
            """
            :type  id: :class:`str`
            :param id: id in message bundle
            :type  default_message: :class:`str`
            :param default_message: text in english
            :type  args: :class:`list` of :class:`str`
            :param args: nested data
            """
            self.id = id
            self.default_message = default_message
            self.args = args
            VapiStruct.__init__(self)


    LocalizableMessage._set_binding_type(type.StructType(
        'com.vmware.appliance.recovery.restore.job.localizable_message', {
            'id': type.StringType(),
            'default_message': type.StringType(),
            'args': type.ListType(type.StringType()),
        },
        LocalizableMessage,
        False,
        None))


    class ReturnResult(VapiStruct):
        """
        ``Job.ReturnResult`` class Structure representing precheck result

        .. tip::
            The arguments are used to initialize data attributes with the same
            names.
        """




        def __init__(self,
                     status=None,
                     messages=None,
                    ):
            """
            :type  status: :class:`Job.ReturnStatus`
            :param status: Check status
            :type  messages: :class:`list` of :class:`Job.LocalizableMessage`
            :param messages: List of messages
            """
            self.status = status
            self.messages = messages
            VapiStruct.__init__(self)


    ReturnResult._set_binding_type(type.StructType(
        'com.vmware.appliance.recovery.restore.job.return_result', {
            'status': type.ReferenceType(__name__, 'Job.ReturnStatus'),
            'messages': type.ListType(type.ReferenceType(__name__, 'Job.LocalizableMessage')),
        },
        ReturnResult,
        False,
        None))


    class RestoreRequest(VapiStruct):
        """
        ``Job.RestoreRequest`` class Structure representing requested restore piece

        .. tip::
            The arguments are used to initialize data attributes with the same
            names.
        """




        def __init__(self,
                     backup_password=None,
                     location_type=None,
                     location=None,
                     location_user=None,
                     location_password=None,
                     sso_admin_user_name=None,
                     sso_admin_user_password=None,
                     ignore_warnings=None,
                    ):
            """
            :type  backup_password: :class:`str` or ``None``
            :param backup_password: a password for a backup piece
                backupPassword If no password then the piece will not be decrypted
            :type  location_type: :class:`Job.LocationType`
            :param location_type: a type of location
            :type  location: :class:`str`
            :param location: path or url
            :type  location_user: :class:`str` or ``None``
            :param location_user: username for location
                locationUser User name for this location if login is required.
            :type  location_password: :class:`str` or ``None``
            :param location_password: password for location
                locationPassword Password for the specified user if login is
                required at this location.
            :type  sso_admin_user_name: :class:`str` or ``None``
            :param sso_admin_user_name: Administrators Username for SSO. This attribute was added in
                vSphere API 6.7.
                If None SSO authentication will not be used. If the vCenter Server
                is a management node or an embedded node, authentication is
                required.
            :type  sso_admin_user_password: :class:`str` or ``None``
            :param sso_admin_user_password: The password for SSO admin user. This attribute was added in
                vSphere API 6.7.
                If None SSO authentication will not be used. If the vCenter Server
                is a management node or an embedded node, authentication is
                required.
            :type  ignore_warnings: :class:`bool` or ``None``
            :param ignore_warnings: The flag to ignore warnings during restore. This attribute was
                added in vSphere API 6.7.
                If None, validation warnings will fail the restore operation
            """
            self.backup_password = backup_password
            self.location_type = location_type
            self.location = location
            self.location_user = location_user
            self.location_password = location_password
            self.sso_admin_user_name = sso_admin_user_name
            self.sso_admin_user_password = sso_admin_user_password
            self.ignore_warnings = ignore_warnings
            VapiStruct.__init__(self)


    RestoreRequest._set_binding_type(type.StructType(
        'com.vmware.appliance.recovery.restore.job.restore_request', {
            'backup_password': type.OptionalType(type.SecretType()),
            'location_type': type.ReferenceType(__name__, 'Job.LocationType'),
            'location': type.StringType(),
            'location_user': type.OptionalType(type.StringType()),
            'location_password': type.OptionalType(type.SecretType()),
            'sso_admin_user_name': type.OptionalType(type.StringType()),
            'sso_admin_user_password': type.OptionalType(type.SecretType()),
            'ignore_warnings': type.OptionalType(type.BooleanType()),
        },
        RestoreRequest,
        False,
        None))


    class RestoreJobStatus(VapiStruct):
        """
        ``Job.RestoreJobStatus`` class Structure representing backup restore status

        .. tip::
            The arguments are used to initialize data attributes with the same
            names.
        """




        def __init__(self,
                     state=None,
                     messages=None,
                     progress=None,
                    ):
            """
            :type  state: :class:`Job.BackupRestoreProcessState`
            :param state: process state
            :type  messages: :class:`list` of :class:`Job.LocalizableMessage`
            :param messages: list of messages
            :type  progress: :class:`long`
            :param progress: percentage complete
            """
            self.state = state
            self.messages = messages
            self.progress = progress
            VapiStruct.__init__(self)


    RestoreJobStatus._set_binding_type(type.StructType(
        'com.vmware.appliance.recovery.restore.job.restore_job_status', {
            'state': type.ReferenceType(__name__, 'Job.BackupRestoreProcessState'),
            'messages': type.ListType(type.ReferenceType(__name__, 'Job.LocalizableMessage')),
            'progress': type.IntegerType(),
        },
        RestoreJobStatus,
        False,
        None))



    def cancel(self):
        """
        Cancel the restore job


        :rtype: :class:`Job.ReturnResult`
        :return: RestoreJobStatus Structure
        :raise: :class:`com.vmware.vapi.std.errors_client.Error` 
            Generic error
        """
        return self._invoke('cancel', None)

    def create(self,
               piece,
               ):
        """
        Initiate restore.

        :type  piece: :class:`Job.RestoreRequest`
        :param piece: RestoreRequest Structure
        :rtype: :class:`Job.RestoreJobStatus`
        :return: RestoreJobStatus Structure
        :raise: :class:`com.vmware.vapi.std.errors_client.FeatureInUse` 
            A backup or restore is already in progress
        :raise: :class:`com.vmware.vapi.std.errors_client.NotAllowedInCurrentState` 
            Restore is allowed only after deployment and before firstboot
        :raise: :class:`com.vmware.vapi.std.errors_client.Error` 
            Generic error
        """
        return self._invoke('create',
                            {
                            'piece': piece,
                            })

    def get(self):
        """
        See restore job progress/result.


        :rtype: :class:`Job.RestoreJobStatus`
        :return: RestoreJobStatus Structure
        :raise: :class:`com.vmware.vapi.std.errors_client.Error` 
            Generic error
        """
        return self._invoke('get', None)
class _JobStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for cancel operation
        cancel_input_type = type.StructType('operation-input', {})
        cancel_error_dict = {
            'com.vmware.vapi.std.errors.error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Error'),

        }
        cancel_input_value_validator_list = [
        ]
        cancel_output_validator_list = [
        ]
        cancel_rest_metadata = OperationRestMetadata(
            http_method='POST',
            url_template='/appliance/recovery/restore/job/cancel',
            path_variables={
            },
             header_parameters={
             },
            query_parameters={
            }
        )

        # properties for create operation
        create_input_type = type.StructType('operation-input', {
            'piece': type.ReferenceType(__name__, 'Job.RestoreRequest'),
        })
        create_error_dict = {
            'com.vmware.vapi.std.errors.feature_in_use':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'FeatureInUse'),
            'com.vmware.vapi.std.errors.not_allowed_in_current_state':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotAllowedInCurrentState'),
            'com.vmware.vapi.std.errors.error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Error'),

        }
        create_input_value_validator_list = [
        ]
        create_output_validator_list = [
        ]
        create_rest_metadata = OperationRestMetadata(
            http_method='POST',
            url_template='/appliance/recovery/restore/job',
            path_variables={
            },
             header_parameters={
               },
            query_parameters={
            }
        )

        # properties for get operation
        get_input_type = type.StructType('operation-input', {})
        get_error_dict = {
            'com.vmware.vapi.std.errors.error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Error'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/appliance/recovery/restore/job',
            path_variables={
            },
             header_parameters={
             },
            query_parameters={
            }
        )

        operations = {
            'cancel': {
                'input_type': cancel_input_type,
                'output_type': type.ReferenceType(__name__, 'Job.ReturnResult'),
                'errors': cancel_error_dict,
                'input_value_validator_list': cancel_input_value_validator_list,
                'output_validator_list': cancel_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'create': {
                'input_type': create_input_type,
                'output_type': type.ReferenceType(__name__, 'Job.RestoreJobStatus'),
                'errors': create_error_dict,
                'input_value_validator_list': create_input_value_validator_list,
                'output_validator_list': create_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType(__name__, 'Job.RestoreJobStatus'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'cancel': cancel_rest_metadata,
            'create': create_rest_metadata,
            'get': get_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.appliance.recovery.restore.job',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=True)


class StubFactory(StubFactoryBase):
    _attrs = {
        'Job': Job,
    }




"""
Factory methods for creating application context
"""

__author__ = 'VMware, Inc.'
__copyright__ = 'Copyright 2015, 2017, 2019 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long


import uuid

from vmware.vapi.common.context import get_context
from vmware.vapi.core import ApplicationContext
from vmware.vapi.lib.constants import OPID, TASK_ID


def create_operation_id():
    """
    Create a new operation id. It is a randomly generated uuid

    :rtype: :class:`str`
    :return: Newly created operation id
    """
    return str(uuid.uuid4())


def create_default_application_context():
    """
    Create a default application context. The
    created context will only have opId.

    :rtype: :class:`vmware.vapi.core.ApplicationContext`
    :return: Newly created application context
    """
    return ApplicationContext({OPID: create_operation_id()})


def insert_operation_id(app_ctx):
    """
    Add an operation id to the application context if there is none present.
    If an operation id is present, then this is a no op.

    :type app_ctx: :class:`vmware.vapi.core.ApplicationContext`
    :param app_ctx: Application context
    """
    if app_ctx and OPID not in app_ctx:
        app_ctx.setdefault(OPID, create_operation_id())


def insert_task_id(app_ctx, task_id):
    """
    Add a task id to the application context.

    :type app_ctx: :class:`vmware.vapi.core.ApplicationContext`
    :param app_ctx: Application Context
    :type task_id: :class:`str`
    :param task_id: Task Id
    """
    if app_ctx is not None:
        app_ctx[TASK_ID] = task_id


def remove_task_id(app_ctx):
    """
    Remove a task id from the application context.

    :type app_ctx: :class:`vmware.vapi.core.ApplicationContext`
    :param app_ctx: Application Context
    """
    if app_ctx is not None:
        app_ctx.pop(TASK_ID, None)


def get_task_id():
    """
    Return task id stored in application context.
    Return None if there's no task id present.

    :rtype: :class:`str`
    :return: Task Id
    """
    ctx = get_context()
    if ctx is not None:
        app_ctx = ctx.application_context
        if app_ctx:
            return app_ctx.get(TASK_ID)

    return None


def insert_header(app_ctx, key, value):
    """
    Add a key, value pair in application context.
    If the key exists override the value.

    :type  app_ctx: :class:`vmware.vapi.core.ApplicationContext`
    :param app_ctx: Application Context
    :type  key: :class:`str`
    :param key: Application context key
    :type  value: :class:`str`
    :param value: Application context key value
    """
    if app_ctx is not None:
        app_ctx[key] = value



# -*- coding: utf-8 -*-
#---------------------------------------------------------------------------
# Copyright 2023 VMware, Inc.  All rights reserved.

# AUTO GENERATED FILE -- DO NOT MODIFY!
#
# vAPI stub file for package com.vmware.vcenter.identity.broker.tenants.
#---------------------------------------------------------------------------

"""
The ``com.vmware.vcenter.identity.broker.tenants_client`` module provides
classes to manage external authentication broker tenant data.

"""

__author__ = 'VMware, Inc.'
__docformat__ = 'restructuredtext en'

import sys
from warnings import warn

from vmware.vapi.bindings import type
from vmware.vapi.bindings.converter import TypeConverter
from vmware.vapi.bindings.enum import Enum
from vmware.vapi.bindings.error import VapiError
from vmware.vapi.bindings.struct import VapiStruct
from vmware.vapi.bindings.stub import (
    ApiInterfaceStub, StubFactoryBase, VapiInterface)
from vmware.vapi.bindings.common import raise_core_exception
from vmware.vapi.data.validator import (UnionValidator, HasFieldsOfValidator)
from vmware.vapi.exception import CoreException
from vmware.vapi.lib.constants import TaskType
from vmware.vapi.lib.rest import OperationRestMetadata


class TokenInfo(VapiStruct):
    """
    The ``TokenInfo`` class contains detailed information about the tenant
    token. This class was added in vSphere API 8.0.1.0.

    .. tip::
        The arguments are used to initialize data attributes with the same
        names.
    """
    BEARER_TOKEN_METHOD_TYPE = "Bearer"
    """
    Class attribute indicating that the security token is a bearer token. This
    class attribute was added in vSphere API 8.0.1.0.

    """




    def __init__(self,
                 token_type=None,
                 access_token=None,
                 expires_in=None,
                ):
        """
        :type  token_type: :class:`str`
        :param token_type: The type of the token issued. The access token type provides the
            client with the information required to successfully utilize the
            access token to make a protected resource request (along with
            type-specific attributes). The client MUST NOT use an access token
            if it does not understand the token type. 
            
            "Bearer" token type as defined in RFC 6750 is supported.. This
            attribute was added in vSphere API 8.0.1.0.
        :type  access_token: :class:`str`
        :param access_token: Tenant client access token issued by the authorization server. This
            attribute was added in vSphere API 8.0.1.0.
        :type  expires_in: :class:`long` or ``None``
        :param expires_in: The lifetime in seconds of the access token. For example, the value
            "3600" denotes that the access token will expire in one hour from
            the time the response was generated. This attribute was added in
            vSphere API 8.0.1.0.
            None if not applicable for issued token.
        """
        self.token_type = token_type
        self.access_token = access_token
        self.expires_in = expires_in
        VapiStruct.__init__(self)


TokenInfo._set_binding_type(type.StructType(
    'com.vmware.vcenter.identity.broker.tenants.token_info', {
        'token_type': type.StringType(),
        'access_token': type.StringType(),
        'expires_in': type.OptionalType(type.IntegerType()),
    },
    TokenInfo,
    False,
    None))



class AdminClient(VapiInterface):
    """
    The ``AdminClient`` interface provides methods to read the token info of
    tenant admin client. The tenant client belongs to the pre-configured
    tenant(s), that were created at bootstrap of vcenter trustmanagement
    service. The tenant admin client tokens can be used to perform API
    invocations within a tenant entity. This class was added in vSphere API
    8.0.1.0.
    """

    _VAPI_SERVICE_ID = 'com.vmware.vcenter.identity.broker.tenants.admin_client'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _AdminClientStub)
        self._VAPI_OPERATION_IDS = {}


    def get(self,
            tenant,
            ):
        """
        Returns the tenant admin client token info associated with
        pre-configured tenant(s) owned by vcenter trustmanagment service. This
        method was added in vSphere API 8.0.1.0.

        :type  tenant: :class:`str`
        :param tenant: The tenant name for which the admin client token needs to be
            returned.
            The parameter must be an identifier for the resource type:
            ``com.vmware.vcenter.identity.broker.tenant``.
        :rtype: :class:`TokenInfo`
        :return: :class:`TokenInfo` class that contains a newly issued tenant admin
            client token.
        :raise: :class:`com.vmware.vapi.std.errors_client.Error` 
            if any other error occurs.
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            if no tenant owned by vcenter trustmanagment service, with the
            input parameter found.
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthenticated` 
            if not authenticated.
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            if not authorized to invoke the operation.
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized`
            if you do not have all of the privileges described as follows: 
            
            * Method execution requires ``VcIdentityProviders.Manage``.
        """
        return self._invoke('get',
                            {
                            'tenant': tenant,
                            })
class OperatorClient(VapiInterface):
    """
    The ``OperatorClient`` interface provides methods to read the token info of
    operator client. The operator client belongs to the pre-configured HWS
    tenant, that was created at bootstrap/installation of broker. The operator
    client tokens can be used to call the tenant management APIs like create,
    get and delete of tenant entity. This class was added in vSphere API
    8.0.1.0.
    """

    _VAPI_SERVICE_ID = 'com.vmware.vcenter.identity.broker.tenants.operator_client'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _OperatorClientStub)
        self._VAPI_OPERATION_IDS = {}


    def get(self):
        """
        Return the operator client token info in Broker. The operator client
        was created at bootstrap or installation of broker. This token can be
        used to manage tenant entity APIs. This method was added in vSphere API
        8.0.1.0.


        :rtype: :class:`TokenInfo`
        :return: :class:`TokenInfo` class that contains a newly issued operator
            client token.
        :raise: :class:`com.vmware.vapi.std.errors_client.Error` 
            if any other error occurs.
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            if no operator client details found.
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthenticated` 
            if not authenticated.
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            if not authorized to invoke the operation.
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized`
            if you do not have all of the privileges described as follows: 
            
            * Method execution requires ``VcIdentityProviders.Manage``.
        """
        return self._invoke('get', None)
class _AdminClientStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for get operation
        get_input_type = type.StructType('operation-input', {
            'tenant': type.IdType(resource_types='com.vmware.vcenter.identity.broker.tenant'),
        })
        get_error_dict = {
            'com.vmware.vapi.std.errors.error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Error'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),
            'com.vmware.vapi.std.errors.unauthenticated':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthenticated'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/vcenter/identity/broker/tenants/{tenant}/admin-client',
            path_variables={
                'tenant': 'tenant',
            },
            query_parameters={
            },
            dispatch_parameters={
            },
            header_parameters={
            },
            dispatch_header_parameters={
            }
        )

        operations = {
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType(__name__, 'TokenInfo'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'get': get_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.vcenter.identity.broker.tenants.admin_client',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=True)

class _OperatorClientStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for get operation
        get_input_type = type.StructType('operation-input', {})
        get_error_dict = {
            'com.vmware.vapi.std.errors.error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Error'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),
            'com.vmware.vapi.std.errors.unauthenticated':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthenticated'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/vcenter/identity/broker/tenants/operator-client',
            path_variables={
            },
            query_parameters={
            },
            dispatch_parameters={
            },
            header_parameters={
            },
            dispatch_header_parameters={
            }
        )

        operations = {
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType(__name__, 'TokenInfo'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'get': get_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.vcenter.identity.broker.tenants.operator_client',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=True)


class StubFactory(StubFactoryBase):
    _attrs = {
        'AdminClient': AdminClient,
        'OperatorClient': OperatorClient,
    }




# -*- coding: utf-8 -*-
#---------------------------------------------------------------------------
# Copyright 2023 VMware, Inc.  All rights reserved.

# AUTO GENERATED FILE -- DO NOT MODIFY!
#
# vAPI stub file for package com.vmware.nsx_vmc_app.infra.external.route.
#---------------------------------------------------------------------------

"""


"""

__author__ = 'VMware, Inc.'
__docformat__ = 'restructuredtext en'

import sys
from warnings import warn

from vmware.vapi.bindings import type
from vmware.vapi.bindings.converter import TypeConverter
from vmware.vapi.bindings.enum import Enum
from vmware.vapi.bindings.error import VapiError
from vmware.vapi.bindings.struct import VapiStruct
from vmware.vapi.bindings.stub import (
    ApiInterfaceStub, StubFactoryBase, VapiInterface)
from vmware.vapi.bindings.common import raise_core_exception
from vmware.vapi.data.validator import (UnionValidator, HasFieldsOfValidator)
from vmware.vapi.exception import CoreException
from vmware.vapi.lib.constants import TaskType
from vmware.vapi.lib.rest import OperationRestMetadata


class Aggregations(VapiInterface):
    """
    
    """

    _VAPI_SERVICE_ID = 'com.vmware.nsx_vmc_app.infra.external.route.aggregations'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _AggregationsStub)
        self._VAPI_OPERATION_IDS = {}


    def delete(self,
               aggregations_id,
               ):
        """
        Delete routeAggregationConfig object for a given aggregationsId

        :type  aggregations_id: :class:`str`
        :param aggregations_id: (required)
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('delete',
                            {
                            'aggregations_id': aggregations_id,
                            })

    def get(self,
            aggregations_id,
            ):
        """
        Get routeAggregationConfig object info for a given aggregationsId.

        :type  aggregations_id: :class:`str`
        :param aggregations_id: (required)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteAggregationConfig`
        :return: com.vmware.nsx_vmc_app.model.RouteAggregationConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('get',
                            {
                            'aggregations_id': aggregations_id,
                            })

    def list(self,
             cursor=None,
             included_fields=None,
             page_size=None,
             sort_ascending=None,
             sort_by=None,
             ):
        """
        Get all routAggregationConfig object available in db.

        :type  cursor: :class:`str` or ``None``
        :param cursor: Opaque cursor to be used for getting next page of records (supplied
            by current result page) (optional)
        :type  included_fields: :class:`str` or ``None``
        :param included_fields: Comma separated list of fields that should be included in query
            result (optional)
        :type  page_size: :class:`long` or ``None``
        :param page_size: Maximum number of results to return in this page (server may return
            fewer) (optional, default to 1000)
        :type  sort_ascending: :class:`bool` or ``None``
        :param sort_ascending: (optional)
        :type  sort_by: :class:`str` or ``None``
        :param sort_by: Field by which records are sorted (optional)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteAggregationConfigListResult`
        :return: com.vmware.nsx_vmc_app.model.RouteAggregationConfigListResult
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('list',
                            {
                            'cursor': cursor,
                            'included_fields': included_fields,
                            'page_size': page_size,
                            'sort_ascending': sort_ascending,
                            'sort_by': sort_by,
                            })

    def update(self,
               route_aggregations_id,
               route_aggregation_config,
               ):
        """
        Create or update the routeAggregation object. This API is used to
        create/update a list of prefixes that customer wants to aggregate.

        :type  route_aggregations_id: :class:`str`
        :param route_aggregations_id: (required)
        :type  route_aggregation_config: :class:`com.vmware.nsx_vmc_app.model_client.RouteAggregationConfig`
        :param route_aggregation_config: (required)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteAggregationConfig`
        :return: com.vmware.nsx_vmc_app.model.RouteAggregationConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('update',
                            {
                            'route_aggregations_id': route_aggregations_id,
                            'route_aggregation_config': route_aggregation_config,
                            })
class Configs(VapiInterface):
    """
    
    """

    _VAPI_SERVICE_ID = 'com.vmware.nsx_vmc_app.infra.external.route.configs'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _ConfigsStub)
        self._VAPI_OPERATION_IDS = {}


    def delete(self,
               route_config_id,
               ):
        """
        Delete routeConfig object for a given route-config-id

        :type  route_config_id: :class:`str`
        :param route_config_id: (required)
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('delete',
                            {
                            'route_config_id': route_config_id,
                            })

    def get(self,
            route_config_id,
            ):
        """
        Get routeConfig object for a given routeConfig id.

        :type  route_config_id: :class:`str`
        :param route_config_id: (required)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteConfig`
        :return: com.vmware.nsx_vmc_app.model.RouteConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('get',
                            {
                            'route_config_id': route_config_id,
                            })

    def list(self,
             cursor=None,
             included_fields=None,
             page_size=None,
             sort_ascending=None,
             sort_by=None,
             ):
        """
        API to retrieve all the routeConfig objects associated with all the
        remote peers.

        :type  cursor: :class:`str` or ``None``
        :param cursor: Opaque cursor to be used for getting next page of records (supplied
            by current result page) (optional)
        :type  included_fields: :class:`str` or ``None``
        :param included_fields: Comma separated list of fields that should be included in query
            result (optional)
        :type  page_size: :class:`long` or ``None``
        :param page_size: Maximum number of results to return in this page (server may return
            fewer) (optional, default to 1000)
        :type  sort_ascending: :class:`bool` or ``None``
        :param sort_ascending: (optional)
        :type  sort_by: :class:`str` or ``None``
        :param sort_by: Field by which records are sorted (optional)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteConfigListResult`
        :return: com.vmware.nsx_vmc_app.model.RouteConfigListResult
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('list',
                            {
                            'cursor': cursor,
                            'included_fields': included_fields,
                            'page_size': page_size,
                            'sort_ascending': sort_ascending,
                            'sort_by': sort_by,
                            })

    def update(self,
               route_config_id,
               route_config,
               ):
        """
        RouteConfig object is to create the mapping between the aggregation and
        the remote source.This api is to create the routeConfig object which
        has the aggrgationConfig and scope information.

        :type  route_config_id: :class:`str`
        :param route_config_id: (required)
        :type  route_config: :class:`com.vmware.nsx_vmc_app.model_client.RouteConfig`
        :param route_config: (required)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteConfig`
        :return: com.vmware.nsx_vmc_app.model.RouteConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('update',
                            {
                            'route_config_id': route_config_id,
                            'route_config': route_config,
                            })
class Filtering(VapiInterface):
    """
    
    """

    _VAPI_SERVICE_ID = 'com.vmware.nsx_vmc_app.infra.external.route.filtering'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _FilteringStub)
        self._VAPI_OPERATION_IDS = {}


    def delete(self):
        """
        This API was used to delete the existing route filtering state for
        connectivity endpoint. Route filtering can now be disabled with PUT
        /infra/external/config, providing the route_filtering_state as false
        for endpoint.


        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('delete', None)

    def get(self):
        """
        This API was used retrieve RouteFiltering state for connectivity
        endpoints. Route filtering state can now be retrieved with GET
        /infra/external/config.


        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteFiltering`
        :return: com.vmware.nsx_vmc_app.model.RouteFiltering
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('get', None)

    def update(self,
               route_filtering,
               ):
        """
        This API was used to enable/disable route filtering state for
        connectivity endpoints. Route filtering can now be enabled with PUT
        /infra/external/config, providing the route_filtering_state as true for
        endpoint.

        :type  route_filtering: :class:`com.vmware.nsx_vmc_app.model_client.RouteFiltering`
        :param route_filtering: (required)
        :rtype: :class:`com.vmware.nsx_vmc_app.model_client.RouteFiltering`
        :return: com.vmware.nsx_vmc_app.model.RouteFiltering
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('update',
                            {
                            'route_filtering': route_filtering,
                            })
class _AggregationsStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for delete operation
        delete_input_type = type.StructType('operation-input', {
            'aggregations_id': type.StringType(),
        })
        delete_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        delete_input_value_validator_list = [
        ]
        delete_output_validator_list = [
        ]
        delete_rest_metadata = OperationRestMetadata(
            http_method='DELETE',
            url_template='/cloud-service/api/v1/infra/external/route/aggregations/{aggregations-id}',
            path_variables={
                'aggregations_id': 'aggregations-id',
            },
             header_parameters={
               },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for get operation
        get_input_type = type.StructType('operation-input', {
            'aggregations_id': type.StringType(),
        })
        get_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/cloud-service/api/v1/infra/external/route/aggregations/{aggregations-id}',
            path_variables={
                'aggregations_id': 'aggregations-id',
            },
             header_parameters={
               },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for list operation
        list_input_type = type.StructType('operation-input', {
            'cursor': type.OptionalType(type.StringType()),
            'included_fields': type.OptionalType(type.StringType()),
            'page_size': type.OptionalType(type.IntegerType()),
            'sort_ascending': type.OptionalType(type.BooleanType()),
            'sort_by': type.OptionalType(type.StringType()),
        })
        list_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        list_input_value_validator_list = [
        ]
        list_output_validator_list = [
        ]
        list_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/cloud-service/api/v1/infra/external/route/aggregations',
            path_variables={
            },
             header_parameters={
                       },
            query_parameters={
                'cursor': 'cursor',
                'included_fields': 'included_fields',
                'page_size': 'page_size',
                'sort_ascending': 'sort_ascending',
                'sort_by': 'sort_by',
            },
            content_type='application/json'
        )

        # properties for update operation
        update_input_type = type.StructType('operation-input', {
            'route_aggregations_id': type.StringType(),
            'route_aggregation_config': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteAggregationConfig'),
        })
        update_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        update_input_value_validator_list = [
        ]
        update_output_validator_list = [
        ]
        update_rest_metadata = OperationRestMetadata(
            http_method='PUT',
            url_template='/cloud-service/api/v1/infra/external/route/aggregations/{route-aggregations-id}',
            request_body_parameter='route_aggregation_config',
            path_variables={
                'route_aggregations_id': 'route-aggregations-id',
            },
             header_parameters={
                 },
            query_parameters={
            },
            content_type='application/json'
        )

        operations = {
            'delete': {
                'input_type': delete_input_type,
                'output_type': type.VoidType(),
                'errors': delete_error_dict,
                'input_value_validator_list': delete_input_value_validator_list,
                'output_validator_list': delete_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteAggregationConfig'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'list': {
                'input_type': list_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteAggregationConfigListResult'),
                'errors': list_error_dict,
                'input_value_validator_list': list_input_value_validator_list,
                'output_validator_list': list_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'update': {
                'input_type': update_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteAggregationConfig'),
                'errors': update_error_dict,
                'input_value_validator_list': update_input_value_validator_list,
                'output_validator_list': update_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'delete': delete_rest_metadata,
            'get': get_rest_metadata,
            'list': list_rest_metadata,
            'update': update_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.nsx_vmc_app.infra.external.route.aggregations',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=False)

class _ConfigsStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for delete operation
        delete_input_type = type.StructType('operation-input', {
            'route_config_id': type.StringType(),
        })
        delete_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        delete_input_value_validator_list = [
        ]
        delete_output_validator_list = [
        ]
        delete_rest_metadata = OperationRestMetadata(
            http_method='DELETE',
            url_template='/cloud-service/api/v1/infra/external/route/configs/{route-config-id}',
            path_variables={
                'route_config_id': 'route-config-id',
            },
             header_parameters={
               },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for get operation
        get_input_type = type.StructType('operation-input', {
            'route_config_id': type.StringType(),
        })
        get_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/cloud-service/api/v1/infra/external/route/configs/{route-config-id}',
            path_variables={
                'route_config_id': 'route-config-id',
            },
             header_parameters={
               },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for list operation
        list_input_type = type.StructType('operation-input', {
            'cursor': type.OptionalType(type.StringType()),
            'included_fields': type.OptionalType(type.StringType()),
            'page_size': type.OptionalType(type.IntegerType()),
            'sort_ascending': type.OptionalType(type.BooleanType()),
            'sort_by': type.OptionalType(type.StringType()),
        })
        list_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        list_input_value_validator_list = [
        ]
        list_output_validator_list = [
        ]
        list_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/cloud-service/api/v1/infra/external/route/configs',
            path_variables={
            },
             header_parameters={
                       },
            query_parameters={
                'cursor': 'cursor',
                'included_fields': 'included_fields',
                'page_size': 'page_size',
                'sort_ascending': 'sort_ascending',
                'sort_by': 'sort_by',
            },
            content_type='application/json'
        )

        # properties for update operation
        update_input_type = type.StructType('operation-input', {
            'route_config_id': type.StringType(),
            'route_config': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteConfig'),
        })
        update_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        update_input_value_validator_list = [
        ]
        update_output_validator_list = [
        ]
        update_rest_metadata = OperationRestMetadata(
            http_method='PUT',
            url_template='/cloud-service/api/v1/infra/external/route/configs/{route-config-id}',
            request_body_parameter='route_config',
            path_variables={
                'route_config_id': 'route-config-id',
            },
             header_parameters={
                 },
            query_parameters={
            },
            content_type='application/json'
        )

        operations = {
            'delete': {
                'input_type': delete_input_type,
                'output_type': type.VoidType(),
                'errors': delete_error_dict,
                'input_value_validator_list': delete_input_value_validator_list,
                'output_validator_list': delete_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteConfig'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'list': {
                'input_type': list_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteConfigListResult'),
                'errors': list_error_dict,
                'input_value_validator_list': list_input_value_validator_list,
                'output_validator_list': list_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'update': {
                'input_type': update_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteConfig'),
                'errors': update_error_dict,
                'input_value_validator_list': update_input_value_validator_list,
                'output_validator_list': update_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'delete': delete_rest_metadata,
            'get': get_rest_metadata,
            'list': list_rest_metadata,
            'update': update_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.nsx_vmc_app.infra.external.route.configs',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=False)

class _FilteringStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for delete operation
        delete_input_type = type.StructType('operation-input', {})
        delete_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        delete_input_value_validator_list = [
        ]
        delete_output_validator_list = [
        ]
        delete_rest_metadata = OperationRestMetadata(
            http_method='DELETE',
            url_template='/cloud-service/api/v1/infra/external/route/filtering',
            path_variables={
            },
             header_parameters={
             },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for get operation
        get_input_type = type.StructType('operation-input', {})
        get_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/cloud-service/api/v1/infra/external/route/filtering',
            path_variables={
            },
             header_parameters={
             },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for update operation
        update_input_type = type.StructType('operation-input', {
            'route_filtering': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteFiltering'),
        })
        update_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        update_input_value_validator_list = [
        ]
        update_output_validator_list = [
        ]
        update_rest_metadata = OperationRestMetadata(
            http_method='PUT',
            url_template='/cloud-service/api/v1/infra/external/route/filtering',
            request_body_parameter='route_filtering',
            path_variables={
            },
             header_parameters={
               },
            query_parameters={
            },
            content_type='application/json'
        )

        operations = {
            'delete': {
                'input_type': delete_input_type,
                'output_type': type.VoidType(),
                'errors': delete_error_dict,
                'input_value_validator_list': delete_input_value_validator_list,
                'output_validator_list': delete_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteFiltering'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'update': {
                'input_type': update_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx_vmc_app.model_client', 'RouteFiltering'),
                'errors': update_error_dict,
                'input_value_validator_list': update_input_value_validator_list,
                'output_validator_list': update_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'delete': delete_rest_metadata,
            'get': get_rest_metadata,
            'update': update_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.nsx_vmc_app.infra.external.route.filtering',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=False)


class StubFactory(StubFactoryBase):
    _attrs = {
        'Aggregations': Aggregations,
        'Configs': Configs,
        'Filtering': Filtering,
    }




# -*- coding: utf-8 -*-
#---------------------------------------------------------------------------
# Copyright 2023 VMware, Inc.  All rights reserved.

# AUTO GENERATED FILE -- DO NOT MODIFY!
#
# vAPI stub file for package com.vmware.nsx.serviceinsertion.services.solution_configs.
#---------------------------------------------------------------------------

"""


"""

__author__ = 'VMware, Inc.'
__docformat__ = 'restructuredtext en'

import sys
from warnings import warn

from vmware.vapi.bindings import type
from vmware.vapi.bindings.converter import TypeConverter
from vmware.vapi.bindings.enum import Enum
from vmware.vapi.bindings.error import VapiError
from vmware.vapi.bindings.struct import VapiStruct
from vmware.vapi.bindings.stub import (
    ApiInterfaceStub, StubFactoryBase, VapiInterface)
from vmware.vapi.bindings.common import raise_core_exception
from vmware.vapi.data.validator import (UnionValidator, HasFieldsOfValidator)
from vmware.vapi.exception import CoreException
from vmware.vapi.lib.constants import TaskType
from vmware.vapi.lib.rest import OperationRestMetadata


class ExtendedSolutionConfig(VapiInterface):
    """
    
    """

    _VAPI_SERVICE_ID = 'com.vmware.nsx.serviceinsertion.services.solution_configs.extended_solution_config'
    """
    Identifier of the service in canonical form.
    """
    def __init__(self, config):
        """
        :type  config: :class:`vmware.vapi.bindings.stub.StubConfiguration`
        :param config: Configuration to be used for creating the stub.
        """
        VapiInterface.__init__(self, config, _ExtendedSolutionConfigStub)
        self._VAPI_OPERATION_IDS = {}


    def create(self,
               service_id,
               solution_config_id,
               extended_solution_config,
               ):
        """
        Adds a extended solution config. Extended Solution Config are service
        level objects, used by the NXGI partner Service inside the SVM.

        :type  service_id: :class:`str`
        :param service_id: (required)
        :type  solution_config_id: :class:`str`
        :param solution_config_id: (required)
        :type  extended_solution_config: :class:`com.vmware.nsx.model_client.ExtendedSolutionConfig`
        :param extended_solution_config: (required)
        :rtype: :class:`com.vmware.nsx.model_client.ExtendedSolutionConfig`
        :return: com.vmware.nsx.model.ExtendedSolutionConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('create',
                            {
                            'service_id': service_id,
                            'solution_config_id': solution_config_id,
                            'extended_solution_config': extended_solution_config,
                            })

    def delete(self,
               service_id,
               solution_config_id,
               ):
        """
        Deletes extended solution config information for a given solution
        config id.

        :type  service_id: :class:`str`
        :param service_id: (required)
        :type  solution_config_id: :class:`str`
        :param solution_config_id: (required)
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('delete',
                            {
                            'service_id': service_id,
                            'solution_config_id': solution_config_id,
                            })

    def get(self,
            service_id,
            solution_config_id,
            ):
        """
        Returns extended solution config information for a given solution
        config id.

        :type  service_id: :class:`str`
        :param service_id: (required)
        :type  solution_config_id: :class:`str`
        :param solution_config_id: (required)
        :rtype: :class:`com.vmware.nsx.model_client.ExtendedSolutionConfig`
        :return: com.vmware.nsx.model.ExtendedSolutionConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('get',
                            {
                            'service_id': service_id,
                            'solution_config_id': solution_config_id,
                            })

    def update(self,
               service_id,
               solution_config_id,
               extended_solution_config,
               ):
        """
        Updates a extended solution config. Extended Solution Config are
        service level objects, used by the NXGI partner Service inside the SVM.

        :type  service_id: :class:`str`
        :param service_id: (required)
        :type  solution_config_id: :class:`str`
        :param solution_config_id: (required)
        :type  extended_solution_config: :class:`com.vmware.nsx.model_client.ExtendedSolutionConfig`
        :param extended_solution_config: (required)
        :rtype: :class:`com.vmware.nsx.model_client.ExtendedSolutionConfig`
        :return: com.vmware.nsx.model.ExtendedSolutionConfig
        :raise: :class:`com.vmware.vapi.std.errors_client.InvalidRequest` 
            Bad Request, Precondition Failed
        :raise: :class:`com.vmware.vapi.std.errors_client.Unauthorized` 
            Forbidden
        :raise: :class:`com.vmware.vapi.std.errors_client.ServiceUnavailable` 
            Service Unavailable
        :raise: :class:`com.vmware.vapi.std.errors_client.InternalServerError` 
            Internal Server Error
        :raise: :class:`com.vmware.vapi.std.errors_client.NotFound` 
            Not Found
        """
        return self._invoke('update',
                            {
                            'service_id': service_id,
                            'solution_config_id': solution_config_id,
                            'extended_solution_config': extended_solution_config,
                            })
class _ExtendedSolutionConfigStub(ApiInterfaceStub):
    def __init__(self, config):
        # properties for create operation
        create_input_type = type.StructType('operation-input', {
            'service_id': type.StringType(),
            'solution_config_id': type.StringType(),
            'extended_solution_config': type.ReferenceType('com.vmware.nsx.model_client', 'ExtendedSolutionConfig'),
        })
        create_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        create_input_value_validator_list = [
        ]
        create_output_validator_list = [
        ]
        create_rest_metadata = OperationRestMetadata(
            http_method='POST',
            url_template='/api/v1/serviceinsertion/services/{service-id}/solution-configs/{solution-config-id}/extended-solution-config',
            request_body_parameter='extended_solution_config',
            path_variables={
                'service_id': 'service-id',
                'solution_config_id': 'solution-config-id',
            },
             header_parameters={
                   },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for delete operation
        delete_input_type = type.StructType('operation-input', {
            'service_id': type.StringType(),
            'solution_config_id': type.StringType(),
        })
        delete_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        delete_input_value_validator_list = [
        ]
        delete_output_validator_list = [
        ]
        delete_rest_metadata = OperationRestMetadata(
            http_method='DELETE',
            url_template='/api/v1/serviceinsertion/services/{service-id}/solution-configs/{solution-config-id}/extended-solution-config',
            path_variables={
                'service_id': 'service-id',
                'solution_config_id': 'solution-config-id',
            },
             header_parameters={
                 },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for get operation
        get_input_type = type.StructType('operation-input', {
            'service_id': type.StringType(),
            'solution_config_id': type.StringType(),
        })
        get_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        get_input_value_validator_list = [
        ]
        get_output_validator_list = [
        ]
        get_rest_metadata = OperationRestMetadata(
            http_method='GET',
            url_template='/api/v1/serviceinsertion/services/{service-id}/solution-configs/{solution-config-id}/extended-solution-config',
            path_variables={
                'service_id': 'service-id',
                'solution_config_id': 'solution-config-id',
            },
             header_parameters={
                 },
            query_parameters={
            },
            content_type='application/json'
        )

        # properties for update operation
        update_input_type = type.StructType('operation-input', {
            'service_id': type.StringType(),
            'solution_config_id': type.StringType(),
            'extended_solution_config': type.ReferenceType('com.vmware.nsx.model_client', 'ExtendedSolutionConfig'),
        })
        update_error_dict = {
            'com.vmware.vapi.std.errors.invalid_request':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InvalidRequest'),
            'com.vmware.vapi.std.errors.unauthorized':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'Unauthorized'),
            'com.vmware.vapi.std.errors.service_unavailable':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'ServiceUnavailable'),
            'com.vmware.vapi.std.errors.internal_server_error':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'InternalServerError'),
            'com.vmware.vapi.std.errors.not_found':
                type.ReferenceType('com.vmware.vapi.std.errors_client', 'NotFound'),

        }
        update_input_value_validator_list = [
        ]
        update_output_validator_list = [
        ]
        update_rest_metadata = OperationRestMetadata(
            http_method='PUT',
            url_template='/api/v1/serviceinsertion/services/{service-id}/solution-configs/{solution-config-id}/extended-solution-config',
            request_body_parameter='extended_solution_config',
            path_variables={
                'service_id': 'service-id',
                'solution_config_id': 'solution-config-id',
            },
             header_parameters={
                   },
            query_parameters={
            },
            content_type='application/json'
        )

        operations = {
            'create': {
                'input_type': create_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx.model_client', 'ExtendedSolutionConfig'),
                'errors': create_error_dict,
                'input_value_validator_list': create_input_value_validator_list,
                'output_validator_list': create_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'delete': {
                'input_type': delete_input_type,
                'output_type': type.VoidType(),
                'errors': delete_error_dict,
                'input_value_validator_list': delete_input_value_validator_list,
                'output_validator_list': delete_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'get': {
                'input_type': get_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx.model_client', 'ExtendedSolutionConfig'),
                'errors': get_error_dict,
                'input_value_validator_list': get_input_value_validator_list,
                'output_validator_list': get_output_validator_list,
                'task_type': TaskType.NONE,
            },
            'update': {
                'input_type': update_input_type,
                'output_type': type.ReferenceType('com.vmware.nsx.model_client', 'ExtendedSolutionConfig'),
                'errors': update_error_dict,
                'input_value_validator_list': update_input_value_validator_list,
                'output_validator_list': update_output_validator_list,
                'task_type': TaskType.NONE,
            },
        }
        rest_metadata = {
            'create': create_rest_metadata,
            'delete': delete_rest_metadata,
            'get': get_rest_metadata,
            'update': update_rest_metadata,
        }
        ApiInterfaceStub.__init__(
            self, iface_name='com.vmware.nsx.serviceinsertion.services.solution_configs.extended_solution_config',
            config=config, operations=operations, rest_metadata=rest_metadata,
            is_vapi_rest=False)


class StubFactory(StubFactoryBase):
    _attrs = {
        'ExtendedSolutionConfig': ExtendedSolutionConfig,
    }




"""
Configuration management for vAPI providers
"""

__author__ = 'VMware, Inc.'
__copyright__ = 'Copyright 2015, 2017 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long

import os
from six.moves import configparser

from vmware.vapi.lib.log import get_vapi_logger

logger = get_vapi_logger(__name__)


class Sections(object):
    """
    Constants for different sections in the config file
    """
    ENDPOINT = 'endpoint'
    JSONRPC = 'jsonrpc'
    LOGGERS = 'loggers'
    LOGGING = 'logging'
    REST = 'rest'
    SSL = 'ssl'
    TASKS = 'tasks'
    AUTHENTICATION_FILTER = 'vmware.vapi.security.authentication_filter'
    AUTHORIZATION_FILTER = 'vmware.vapi.security.authorization_filter'


class EndpointSection(object):
    """
    Constants for keys/prefixes/suffixes in Endpoint section in config file
    """
    PROVIDER_TYPE = 'provider.type'
    PROVIDER_NAME = 'provider.name'
    INTERFACE_LIST = 'local.interfaces'
    AGGREGATOR_CHILDREN = 'aggregator.children'
    AGGREGATOR_CHILD_PREFIX = 'aggregator.child'
    PROTOCOL_PREFIX = 'protocol'
    PROTOCOL_RPC_SUFFIX = 'rpc'
    PROTOCOL_RPC_SERVER_SUFFIX = 'rpc.server'
    PROTOCOL_URL_SUFFIX = 'url'
    PROTOCOL_MSG_SUFFIX = 'msg'
    PROTOCOL_SSL_SUFFIX = 'ssl'


class TasksSection(object):
    """
    Constants for keys/prefixes/suffixes in Tasks section in config file
    """
    THREADS = 'threads'
    TASK_MANAGER = 'task_manager'
    PRIVILEGE_VALIDATOR = 'privilege_validator'


def check_file_exists(filename):
    """
    Check if name is a file and exists

    :type  :class:`str`
    :param file name
    """
    if not os.path.exists(filename) or not os.path.isfile(filename):
        raise os.error(2, "No such file: '%s'" % filename)


class ProviderConfig(object):
    """
    Provider Configuration class that provides methods for configuring different
    aspects of the VAPI Server
    """
    def __init__(self, config_file=None):
        """
        Initialize ProviderConfig

        :type  config_file: :class:`str`
        :param config_file: Path of the config file
        """
        self.cfg = None
        if config_file:
            check_file_exists(config_file)
            self.cfg = configparser.SafeConfigParser()
            self.cfg.read(config_file)

    def _get_value(self, section_name, option_name, default_value=None):
        """
        Get the configuration value for the given section and option.

        :type  section_name: :class:`str`
        :param section_name: Name of the section in the configuration file.
        :type  option_name: :class:`str`
        :param option_name: Name of the option in the configuration file.
        :type  default_value: :class:`object`
        :param default_value: Default value to be returned if section or option
            is not present in the configuration.
        :rtype: :class:`str`
        :return: String value for the key. If the section or option is not
            present, the operation will return the default value provided
        """
        if self.cfg.has_section(section_name) and self.cfg.has_option(
                section_name, option_name):
            return self.cfg.get(section_name, option_name)
        else:
            return default_value

    def _parse_list(self, list_val):
        """
        Get list of parsed strings stripped off the delimiters and whitespaces

        :type  list_val: :class:`str`
        :param list_val: Comma separated string possibly containing delimiters
        :rtype: :class:`list` of :class:`str`
        :return: List of names of session login methods
        """
        return_val = []
        if list_val is not None:
            if ',' in list_val:
                return_val = \
                    list_val.replace('\n', '').replace('\\', '').split(',')
                return_val = [r.strip() for r in return_val]
            else:
                return_val = [list_val.strip()]
        return return_val

    def get_providers(self):
        """
        Get provider chain

        :rtype: :class:`list` of :class:`str`
        :return: List of providers in a chain
        """
        providers = self._get_value(
            Sections.ENDPOINT, EndpointSection.PROVIDER_TYPE)
        if providers:
            return self._parse_list(providers)
        return []

    def get_provider_name(self):
        """
        Get provider name

        :rtype: :class:`str`
        :return: Name of the provider key used in the config file
        """
        return self._get_value(
            Sections.ENDPOINT, EndpointSection.PROVIDER_NAME)

    def get_provider_protocols(self):
        """
        Get protol names

        :rtype: :class:`list` of :class:`str`
        :return: List of protocol names
        """
        return self._get_value(
            Sections.ENDPOINT, EndpointSection.PROTOCOL_PREFIX).split(',')

    def get_provider_url(self, protocol):
        """
        Get provider URL

        :type  protocol: :class:`str`
        :param protocol: Protocol key name
        :rtype: :class:`str` or :class:`None`
        :return: Provider URL
        """
        rpc_key = '%s.%s.%s' % (
            EndpointSection.PROTOCOL_PREFIX, protocol,
            EndpointSection.PROTOCOL_RPC_SUFFIX)
        url = self._get_value(Sections.ENDPOINT, rpc_key)
        if url == 'wsgi':
            url_key = '%s.%s.%s' % (
                EndpointSection.PROTOCOL_PREFIX, protocol,
                EndpointSection.PROTOCOL_URL_SUFFIX)
            url = self._get_value(Sections.ENDPOINT, url_key)
        return url

    def get_provider_ssl_args(self, protocol):
        """
        Extract the ssl arguments

        :type  cfg: :class:`configparser.SafeConfigParser`
        :param cfg: Configuration
        :type  protocol_prefix: :class:`str`
        :param protocol_prefix: Prefix of the protocol configuration
        :rtype: :class:`dict`
        :return: SSL arguments for this protocol configuration
        """
        ssl_args = {}

        # Try to get the certdir from environment variable or .certdir option
        certdir = os.environ.get('CERTDIR')
        if certdir is None:
            try:
                certdir_key = '%s.%s.%s.certdir' % (
                    EndpointSection.PROTOCOL_PREFIX, protocol,
                    EndpointSection.PROTOCOL_SSL_SUFFIX)
                certdir = self._get_value(Sections.ENDPOINT, certdir_key)
            except configparser.NoOptionError:
                # But don't complain yet
                pass

        for ssl_key in ('ca_certs', 'certfile', 'keyfile'):
            option = '%s.%s.%s.%s' % (
                EndpointSection.PROTOCOL_PREFIX, protocol,
                EndpointSection.PROTOCOL_SSL_SUFFIX, ssl_key)
            file_name = None
            try:
                file_name = self._get_value(Sections.ENDPOINT, option)
            except configparser.NoOptionError:
                # ca_certs, certfile and keyfile are optional, so don't complain
                # if they are not present
                pass

            if file_name is not None:
                if certdir is None:
                    # If one of ca_certs, certfile, keyfile is specified
                    # and certdir is not specified, then raise an error
                    logger.error('Specify certificate absolute directory path '
                                 'either by setting environment variable '
                                 'CERTDIR or by setting %s.certdir in the '
                                 'properties file',
                                 EndpointSection.PROTOCOL_SSL_SUFFIX)
                    raise configparser.NoOptionError(
                        '%s.certdir' % EndpointSection.PROTOCOL_SSL_SUFFIX,
                        Sections.ENDPOINT)
                else:
                    file_path = os.path.join(certdir, file_name)
                    check_file_exists(file_path)
                    ssl_args[ssl_key] = file_path
        return ssl_args

    def get_provider_server(self, protocol):
        """
        Get http server type

        :type  protocol: :class:`str`
        :param protocol: Protocol key name
        :rtype: :class:`str` or :class:`None`
        :return: Server type
        """
        server_key = '%s.%s.%s' % (
            EndpointSection.PROTOCOL_PREFIX, protocol,
            EndpointSection.PROTOCOL_RPC_SERVER_SUFFIX)
        return self._get_value(Sections.ENDPOINT, server_key)

    def get_provider_message_format(self, protocol):
        """
        Get provider message format

        :type  protocol: :class:`str`
        :param protocol: Protocol key name
        :rtype: :class:`str` or :class:`None`
        :return: Message format for the provider
        """
        msg_key = '%s.%s.%s' % (
            EndpointSection.PROTOCOL_PREFIX, protocol,
            EndpointSection.PROTOCOL_MSG_SUFFIX)
        return self._get_value(Sections.ENDPOINT, msg_key)

    def get_jsonrpc_prefix(self):
        """
        Get JSONRPC prefix

        :rtype: :class:`str`
        :return: JSONRPC prefix
        """
        return self._get_value(Sections.JSONRPC, 'prefix')

    def get_rest_prefix(self):
        """
        Get REST prefix

        :rtype: :class:`str`
        :return: REST prefix
        """
        return self._get_value(Sections.REST, 'prefix')

    def enable_rest(self):
        """
        Whether REST is to be enabled

        :rtype: :class:`bool`
        :return: Whether REST is to be enabled
        """
        return self.cfg.has_section(Sections.REST)

    def are_cookies_supported(self):
        """
        Whether cookies are to be enabled

        :rtype: :class:`bool`
        :return: Whether cookies are to be enabled
        """
        if self.cfg.has_option(Sections.REST, 'allow_cookies'):
            return self.cfg.getboolean(Sections.REST, 'allow_cookies')
        return True

    def get_rest_security_parsers(self):
        """
        Get REST security parsers

        :rtype: :class:`list` of :class:`str`
        :return: List of security parsers for REST
        """
        parsers = self._get_value(Sections.REST, 'security_parsers')
        return self._parse_list(parsers)

    def get_rest_session_methods(self):
        """
        Get REST session methods

        :rtype: :class:`list` of :class:`str`
        :return: List of names of session login methods
        """
        parsers = self._get_value(Sections.REST, 'session_methods')
        return self._parse_list(parsers)

    def get_interfaces(self):
        """
        Get interfaces

        :rtype: :class:`list` of :class:`str`
        :return: List of names of interfaces
        """
        ifaces = self._get_value(
            Sections.ENDPOINT, EndpointSection.INTERFACE_LIST)
        if ifaces:
            return self._parse_list(ifaces)
        return []

    def get_service_config(self, service):
        """
        Get service configuration

        :rtype: :class:`dict`
        :return: Dictionary object containing service configuration
        """
        if self.cfg.has_section(service):
            return dict(self.cfg.items(service))
        return {}

    def are_tasks_enabled(self):
        """
        Whether Tasks are enabled

        :rtype: :class:`bool`
        :return: Whether Tasks are enabled
        """
        return self.cfg.has_section(Sections.TASKS)

    def get_provider_task_threads(self):
        """
        Get provider threads
        """
        if self.cfg.has_option(Sections.TASKS, TasksSection.THREADS):
            return self.cfg.getint(Sections.TASKS, TasksSection.THREADS)

        # Default to 3 threads for tasks operations
        # TODO: remove when simplifying provider config defaults
        return 3

    def get_provider_task_manager(self):
        """
        Get provider task manager
        """
        return self._get_value(Sections.TASKS, TasksSection.TASK_MANAGER)

    def get_provider_privilege_validator(self):
        """
        Get provider privilege validator
        """
        return self._get_value(Sections.TASKS, TasksSection.PRIVILEGE_VALIDATOR)

    def get_child_providers(self):
        """
        Get child providers

        :rtype: :class:`list` of :class:`str`
        :return: List of names of child providers
        """
        child_providers = self._get_value(
            Sections.ENDPOINT, EndpointSection.AGGREGATOR_CHILDREN)
        if child_providers:
            return self._parse_list(child_providers)
        return []

    def get_child_url(self, child):
        """
        Get child provider URL

        :type  child: :class:`str`
        :param child: Name of the child provider key
        :rtype: :class:`str`
        :return: URL of the child provider
        """
        return self._get_value(
            Sections.ENDPOINT,
            '%s.%s.protocol.rpc' % (
                EndpointSection.AGGREGATOR_CHILD_PREFIX, child))

    def get_authentication_handlers(self):
        """
        Get authentication handlers

        :rtype: :class:`list` of :class:`str`
        :return: List of authentication handlers
        """
        handlers = self._get_value(
            Sections.AUTHENTICATION_FILTER, 'handlers')
        if handlers:
            return self._parse_list(handlers)
        return []

    def get_authorization_handlers_and_files(self):
        """
        Get authorization handlers and authentication file

        :rtype: :class:`tuple` of :class:`list` of :class:`str` and :class:`str`
        :return: Tuple of list of authorization handlers and authentication file
        """
        handlers = self._get_value(
            Sections.AUTHORIZATION_FILTER, 'handlers')
        if handlers:
            files = self._get_value(Sections.AUTHORIZATION_FILTER, 'file')
            files_list = self._parse_list(files) if files else []
            return (
                self._parse_list(handlers),
                files_list)
        return ([], [])
